![image info](./images/qfi-opt.png)

This repository contains codes for optimizing the [quantum fisher information (QFI)](https://en.wikipedia.org/wiki/Quantum_Fisher_information) of quantum systems.

## Installation

This package requires Python>=3.10, and can be installed from PyPI with
```
pip install qfi-opt
```
To install from source:
```
git clone https://github.com/jmlarson1/QFI-Opt.git
pip install -e QFI-Opt
```
